# VisionSuite

This is just personal repository to easily use oepn source algorithms.

## Cores

### Roboflow 

#### Ultralytics

- HBB Detection

- OBB Detection
 
- Instance Segmentation


## How to publish github-repository to PYPI

```cmd
git add .
git commit -m 'publish v1.x.x'
git tag v.1.x.x
git push origin --tags
```